# entsopy

Your cli tool for **download data from the** from ENTSO-E transparency platform.
**Please note that a security token is mandatory for accessing the ENTSO-E API service.**

## Useful links

- **Ensto-e official website:** https://www.entsoe.eu/
- **Ensto-e transparency platform:** https://transparency.entsoe.eu/
- **Ensto-e security token:** https://transparency.entsoe.eu/content/static_content/Static%20content/web%20api/Guide html#_authentication_and_authorisation